@@ -21,8 +21,8 @@
  * @author Sam Meder, Sam Lang
  *
  * $RCSfile: globus_gsi_callback.c,v $
- * $Revision: 1.40 $
- * $Date: 2008/09/11 17:36:54 $
+ * $Revision: 1.40.4.2 $
+ * $Date: 2010/07/02 19:09:44 $
  */
 #endif
 
@@ -392,7 +392,7 @@ globus_gsi_callback_X509_verify_cert(
      * errors and returns success. globus_i_gsi_callback_cred_verify() 
      * will check the critical extension later.
      */
-    #if (OPENSSL_VERSION_NUMBER >= 0x0090800fL)
+    #if defined(X509_V_FLAG_ALLOW_PROXY_CERTS)
     X509_STORE_CTX_set_flags(
                    context, X509_V_FLAG_ALLOW_PROXY_CERTS);
     #endif
@@ -1517,8 +1517,8 @@ globus_i_gsi_callback_check_critical_extensions(
 
     GLOBUS_I_GSI_CALLBACK_DEBUG_ENTER;
 
-    pci_NID = OBJ_sn2nid(PROXYCERTINFO_SN);
-    pci_old_NID = OBJ_sn2nid(PROXYCERTINFO_OLD_SN);
+    pci_NID = OBJ_txt2nid(PROXYCERTINFO_OID);
+    pci_old_NID = OBJ_txt2nid(PROXYCERTINFO_OLD_OID);
 
     while((critical_position = 
           X509_get_ext_by_critical(x509_context->current_cert, 
